@@ -1,14 +1,12 @@
 package Algorithm::Evolutionary::Op::Animated_GIF_Output;
 
-use lib qw( ../../../../lib 
-	    ../../../lib
-	    ../../../../../../Algorithm-Evolutionary/lib ../Algorithm-Evolutionary/lib ); #For development and perl syntax mode
+use lib qw( ../../../../../../Algorithm-Evolutionary/lib ../Algorithm-Evolutionary/lib ); #For development and perl syntax mode
 
 use warnings;
 use strict;
 use Carp;
 
-our $VERSION =   sprintf "%d.%03d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/g; 
+our $VERSION =   sprintf "%d.%03d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/g; 
 
 use base 'Algorithm::Evolutionary::Op::Base';
 
@@ -18,7 +16,6 @@ sub new {
   my $class = shift;
   my $hash = shift || croak "No default values for length ";
   my $self = Algorithm::Evolutionary::Op::Base::new( __PACKAGE__, 1, $hash );
-  $hash->{'pixels_per_bit'} = $hash->{'pixels_per_bit'} || 1;
   $self->{'_image'} = GD::Image->new($hash->{'length'}*$hash->{'pixels_per_bit'},
 				     $hash->{'number_of_strings'}*$hash->{'pixels_per_bit'});
   $self->{'_length'} = $hash->{'length'};
@@ -37,15 +34,16 @@ sub apply {
     my $frame  = GD::Image->new($self->{'_image'}->getBounds);
     my $ppb = $self->{'_pixels_per_bit'};
     my $l=0;
-    for my $i (@$population_hashref) {
-      my $bit_string = $i->{'_str'};
+    for my $p (@$population_hashref) {
+      my $bit_string = $p->{'_str'};
       for my $c ( 0..($self->{'_length'}-1) ) {
 	my $bit = substr( $bit_string, $c, 1 );
 	if ( $bit ) {
 	  for my $p ( 1..$ppb ) {
 	    for my $q (1..$ppb ) {
-	      $frame->setPixel($l*$ppb+$q, $c*$ppb+$p,
-			       $self->{'_black'})
+
+	      $frame->setPixel($c*$ppb+$p,
+			       $l*$ppb+$q,$self->{'_black'})
 	    }
 	  }
 	}
@@ -71,7 +69,7 @@ __END__
 
 =head1 NAME
 
-Algorithm::Evolutionary::Op::Animated_GIF_Output - Creates an animated GIF, a frame per generation. Useful for binary strings.
+ Algorithm::Evolutionary::Op::Animated_GIF_Output - Flexible population printing class
 
 
 =head1 SYNOPSIS
@@ -79,39 +77,29 @@ Algorithm::Evolutionary::Op::Animated_GIF_Output - Creates an animated GIF, a fr
   my $pp = new Algorithm::Evolutionary::Op::Animated_GIF_Output; 
 
   my @pop;
-  my $length = 8;
-  my $number_of_strings = 10;
-  for ( 1..$number_of_strings ) {
-    my $indi= new Algorithm::Evolutionary::Individual::String [0,1], $length;
+  for ( 1..10 ) {
+    my $indi= new Algorithm::Evolutionary::Individual::String [0,1], 8;
     push @pop, $indi;
   }
 
   $pp->apply( \@pop );
-  my $options = { pixels_per_bit => 2,
-                  length => $length,
-                  number_of_strings => $number_of_strings };
 
-  $pp = new Algorithm::Evolutionary::Op::Animated_GIF_Output $options
+  $pp = new Algorithm::Evolutionary::Op::Animated_GIF_Output;
 
   $pp->apply( \@pop );
-  $pp->terminate();
-  my $output_gif = $pp->output(); # Prints final results
+  $pp->output(); # Prints final results
 
 =head1 DESCRIPTION
 
-Saves each generation as a frame in an animated GIF. Every individual
-gets a line of the number of pixels specified, and bits set to "1" are
-represented via black pixels or fat pixels. By default, a bit takes a
-single pixel. 
+Saves each generation as a frame in an animated GIF
 
 =head1 INTERFACE 
 
-=head2 new( [$hash_ref] )
+=head2 new( [$printer] )
 
-C<$hash_ref> is a hashref with 3 options: C<pixels_per_bit>, which
-defaults to 1, and C<length> and C<number_of_strings> which have no
-default and need to be set in advance to set up the GIF before any
-population individual is seen.
+C<$printer> is a closure or reference to function that receives as
+input a single population member. By default, calls C<as_string> on
+each one followed by a carriage return
 
 =head2 apply( $population_hashref )
 
@@ -119,11 +107,18 @@ Applies the single-member printing function to every population member
 
 =head2 terminate()
 
-Finish the setup of the animated GIF.
+Finish the setup of the animated gif
 
 =head2 output()
 
-Returns the animaged GIF; must be assigned to a variable.
+Returns the animaged GIF
+
+=head1 DEPENDENCIES
+
+Main dependence is L<Algorithm::Evolutionary>; however, it's not
+included by default, since you must pick and choose the modules you
+are going to actually use.
+
 
 =head1 INCOMPATIBILITIES
 
@@ -134,7 +129,7 @@ None reported.
 No bugs have been reported.
 
 Please report any bugs or feature requests to
-C<bug-algorithm-evolutionary@rt.cpan.org>, or through the web interface at
+C<bug-poe-component-algorithm-evolutionary@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
 
@@ -144,14 +139,13 @@ JJ Merelo  C<< <jj@merelo.net> >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2009, JJ Merelo C<< <jj@merelo.net> >>. All rights
-reserved. 
+Copyright (c) 2009, JJ Merelo C<< <jj@merelo.net> >>. All rights reserved.
 
-This file is released under the GPL. See the LICENSE file included in this distribution,
-  or go to http://www.fsf.org/licenses/gpl.txt
+This module is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself. See L<perlartistic>.
 
-  CVS Info: $Date: 2010/12/19 21:39:12 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Animated_GIF_Output.pm,v 1.5 2010/12/19 21:39:12 jmerelo Exp $ 
+  CVS Info: $Date: 2009/07/27 16:20:24 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Animated_GIF_Output.pm,v 1.2 2009/07/27 16:20:24 jmerelo Exp $ 
   $Author: jmerelo $ 
 
 =head1 DISCLAIMER OF WARRANTY
